==> rivendell-2.15.3.tar.gz: rivendell-2.15.3/rdlogin/rdlogin_cs.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>MainWidget</name>
    <message>
        <source>RDLogin - Station:</source>
        <translation>RDLogin - Stanice:</translation>
    </message>
    <message>
        <source>rdlogin : </source>
        <translation>rdlogin :</translation>
    </message>
    <message>
        <source>Can&apos;t Connect</source>
        <translation>Nelze spojit</translation>
    </message>
    <message>
        <source>Current User: unknown</source>
        <translation>Nynější uživatel: neznámý</translation>
    </message>
    <message>
        <source>&amp;Username:</source>
        <translation>&amp;Uživatelské jméno:</translation>
    </message>
    <message>
        <source>&amp;Password:</source>
        <translation>He&amp;slo:</translation>
    </message>
    <message>
        <source>&amp;Set User</source>
        <translation>&amp;Nastavit uživatele</translation>
    </message>
    <message>
        <source>&amp;Default
User</source>
        <translation>&amp;Výchozí
uživatel</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Z&amp;rušit</translation>
    </message>
    <message>
        <source>Current User:</source>
        <translation>Nynější uživatel:</translation>
    </message>
    <message>
        <source>RDLogin</source>
        <translation>RDLogin</translation>
    </message>
    <message>
        <source>Invalid Password!</source>
        <translation>Ungültiges Paßwort!</translation>
    </message>
</context>
</TS>

==> rivendell-2.19.0.tar.gz: rivendell-2.19.0/rdlogin/rdlogin_cs.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>MainWidget</name>
    <message>
        <source>RDLogin - Station:</source>
        <translation>RDLogin - Stanice:</translation>
    </message>
    <message>
        <source>rdlogin : </source>
        <translation>rdlogin :</translation>
    </message>
    <message>
        <source>Can&apos;t Connect</source>
        <translation>Nelze spojit</translation>
    </message>
    <message>
        <source>Current User: unknown</source>
        <translation>Nynější uživatel: neznámý</translation>
    </message>
    <message>
        <source>&amp;Username:</source>
        <translation>&amp;Uživatelské jméno:</translation>
    </message>
    <message>
        <source>&amp;Password:</source>
        <translation>He&amp;slo:</translation>
    </message>
    <message>
        <source>&amp;Set User</source>
        <translation>&amp;Nastavit uživatele</translation>
    </message>
    <message>
        <source>&amp;Default
User</source>
        <translation>&amp;Výchozí
uživatel</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Z&amp;rušit</translation>
    </message>
    <message>
        <source>Current User:</source>
        <translation>Nynější uživatel:</translation>
    </message>
    <message>
        <source>RDLogin</source>
        <translation>RDLogin</translation>
    </message>
    <message>
        <source>Invalid Password!</source>
        <translation type="obsolete">Ungültiges Paßwort!</translation>
    </message>
    <message>
        <source>Invalid Username or Password!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
